<?php
/**
 * Internationalization helper.
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2016, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/https://opensource.org/licenses/MIT
 * @since       1.0
 */

if ( ! class_exists( 'Kirki_l10n' ) ) {

    /**
     * Handles translations
     */
    class Kirki_l10n {

        /**
         * The plugin kickstart
         *
         * @access protected
         * @var string
         */
        protected $kickstart = 'kickstart-business';

        /**
         * The class constructor.
         * Adds actions & filters to handle the rest of the methods.
         *
         * @access public
         */
        public function __construct() {

            add_action( 'plugins_loaded', array( $this, 'load_kickstart' ) );

        }

        /**
         * Load the plugin kickstart
         *
         * @access public
         */
        public function load_kickstart() {

            if ( null !== $this->get_path() ) {
                load_kickstart( $this->kickstart, $this->get_path() );
            }
            load_plugin_kickstart( $this->kickstart, false, Kirki::$path . '/languages' );

        }

        /**
         * Gets the path to a translation file.
         *
         * @access protected
         * @return string Absolute path to the translation file.
         */
        protected function get_path() {
            $path_found = false;
            $found_path = null;
            foreach ( $this->get_paths() as $path ) {
                if ( $path_found ) {
                    continue;
                }
                $path = wp_normalize_path( $path );
                if ( file_exists( $path ) ) {
                    $path_found = true;
                    $found_path = $path;
                }
            }

            return $found_path;

        }

        /**
         * Returns an array of paths where translation files may be located.
         *
         * @access protected
         * @return array
         */
        protected function get_paths() {

            return array(
                WP_LANG_DIR . '/' . $this->kickstart . '-' . get_locale() . '.mo',
                Kirki::$path . '/languages/' . $this->kickstart . '-' . get_locale() . '.mo',
            );

        }

        /**
         * Shortcut method to get the translation strings
         *
         * @static
         * @access public
         * @param string $config_id The config ID. See Kirki_Config.
         * @return array
         */
        public static function get_strings( $config_id = 'global' ) {

            $translation_strings = array(
                'background-color'      => esc_attr__( 'Background Color', 'kickstart-business' ),
                'background-image'      => esc_attr__( 'Background Image', 'kickstart-business' ),
                'no-repeat'             => esc_attr__( 'No Repeat', 'kickstart-business' ),
                'repeat-all'            => esc_attr__( 'Repeat All', 'kickstart-business' ),
                'repeat-x'              => esc_attr__( 'Repeat Horizontally', 'kickstart-business' ),
                'repeat-y'              => esc_attr__( 'Repeat Vertically', 'kickstart-business' ),
                'inherit'               => esc_attr__( 'Inherit', 'kickstart-business' ),
                'background-repeat'     => esc_attr__( 'Background Repeat', 'kickstart-business' ),
                'cover'                 => esc_attr__( 'Cover', 'kickstart-business' ),
                'contain'               => esc_attr__( 'Contain', 'kickstart-business' ),
                'background-size'       => esc_attr__( 'Background Size', 'kickstart-business' ),
                'fixed'                 => esc_attr__( 'Fixed', 'kickstart-business' ),
                'scroll'                => esc_attr__( 'Scroll', 'kickstart-business' ),
                'background-attachment' => esc_attr__( 'Background Attachment', 'kickstart-business' ),
                'left-top'              => esc_attr__( 'Left Top', 'kickstart-business' ),
                'left-center'           => esc_attr__( 'Left Center', 'kickstart-business' ),
                'left-bottom'           => esc_attr__( 'Left Bottom', 'kickstart-business' ),
                'right-top'             => esc_attr__( 'Right Top', 'kickstart-business' ),
                'right-center'          => esc_attr__( 'Right Center', 'kickstart-business' ),
                'right-bottom'          => esc_attr__( 'Right Bottom', 'kickstart-business' ),
                'center-top'            => esc_attr__( 'Center Top', 'kickstart-business' ),
                'center-center'         => esc_attr__( 'Center Center', 'kickstart-business' ),
                'center-bottom'         => esc_attr__( 'Center Bottom', 'kickstart-business' ),
                'background-position'   => esc_attr__( 'Background Position', 'kickstart-business' ),
                'background-opacity'    => esc_attr__( 'Background Opacity', 'kickstart-business' ),
                'on'                    => esc_attr__( 'ON', 'kickstart-business' ),
                'off'                   => esc_attr__( 'OFF', 'kickstart-business' ),
                'all'                   => esc_attr__( 'All', 'kickstart-business' ),
                'cyrillic'              => esc_attr__( 'Cyrillic', 'kickstart-business' ),
                'cyrillic-ext'          => esc_attr__( 'Cyrillic Extended', 'kickstart-business' ),
                'devanagari'            => esc_attr__( 'Devanagari', 'kickstart-business' ),
                'greek'                 => esc_attr__( 'Greek', 'kickstart-business' ),
                'greek-ext'             => esc_attr__( 'Greek Extended', 'kickstart-business' ),
                'khmer'                 => esc_attr__( 'Khmer', 'kickstart-business' ),
                'latin'                 => esc_attr__( 'Latin', 'kickstart-business' ),
                'latin-ext'             => esc_attr__( 'Latin Extended', 'kickstart-business' ),
                'vietnamese'            => esc_attr__( 'Vietnamese', 'kickstart-business' ),
                'hebrew'                => esc_attr__( 'Hebrew', 'kickstart-business' ),
                'arabic'                => esc_attr__( 'Arabic', 'kickstart-business' ),
                'bengali'               => esc_attr__( 'Bengali', 'kickstart-business' ),
                'gujarati'              => esc_attr__( 'Gujarati', 'kickstart-business' ),
                'tamil'                 => esc_attr__( 'Tamil', 'kickstart-business' ),
                'telugu'                => esc_attr__( 'Telugu', 'kickstart-business' ),
                'thai'                  => esc_attr__( 'Thai', 'kickstart-business' ),
                'serif'                 => _x( 'Serif', 'font style', 'kickstart-business' ),
                'sans-serif'            => _x( 'Sans Serif', 'font style', 'kickstart-business' ),
                'monospace'             => _x( 'Monospace', 'font style', 'kickstart-business' ),
                'font-family'           => esc_attr__( 'Font Family', 'kickstart-business' ),
                'font-size'             => esc_attr__( 'Font Size', 'kickstart-business' ),
                'font-weight'           => esc_attr__( 'Font Weight', 'kickstart-business' ),
                'line-height'           => esc_attr__( 'Line Height', 'kickstart-business' ),
                'font-style'            => esc_attr__( 'Font Style', 'kickstart-business' ),
                'letter-spacing'        => esc_attr__( 'Letter Spacing', 'kickstart-business' ),
                'top'                   => esc_attr__( 'Top', 'kickstart-business' ),
                'bottom'                => esc_attr__( 'Bottom', 'kickstart-business' ),
                'left'                  => esc_attr__( 'Left', 'kickstart-business' ),
                'right'                 => esc_attr__( 'Right', 'kickstart-business' ),
                'center'                => esc_attr__( 'Center', 'kickstart-business' ),
                'justify'               => esc_attr__( 'Justify', 'kickstart-business' ),
                'color'                 => esc_attr__( 'Color', 'kickstart-business' ),
                'add-image'             => esc_attr__( 'Add Image', 'kickstart-business' ),
                'change-image'          => esc_attr__( 'Change Image', 'kickstart-business' ),
                'no-image-selected'     => esc_attr__( 'No Image Selected', 'kickstart-business' ),
                'add-file'              => esc_attr__( 'Add File', 'kickstart-business' ),
                'change-file'           => esc_attr__( 'Change File', 'kickstart-business' ),
                'no-file-selected'      => esc_attr__( 'No File Selected', 'kickstart-business' ),
                'remove'                => esc_attr__( 'Remove', 'kickstart-business' ),
                'select-font-family'    => esc_attr__( 'Select a font-family', 'kickstart-business' ),
                'variant'               => esc_attr__( 'Variant', 'kickstart-business' ),
                'subsets'               => esc_attr__( 'Subset', 'kickstart-business' ),
                'size'                  => esc_attr__( 'Size', 'kickstart-business' ),
                'height'                => esc_attr__( 'Height', 'kickstart-business' ),
                'spacing'               => esc_attr__( 'Spacing', 'kickstart-business' ),
                'ultra-light'           => esc_attr__( 'Ultra-Light 100', 'kickstart-business' ),
                'ultra-light-italic'    => esc_attr__( 'Ultra-Light 100 Italic', 'kickstart-business' ),
                'light'                 => esc_attr__( 'Light 200', 'kickstart-business' ),
                'light-italic'          => esc_attr__( 'Light 200 Italic', 'kickstart-business' ),
                'book'                  => esc_attr__( 'Book 300', 'kickstart-business' ),
                'book-italic'           => esc_attr__( 'Book 300 Italic', 'kickstart-business' ),
                'regular'               => esc_attr__( 'Normal 400', 'kickstart-business' ),
                'italic'                => esc_attr__( 'Normal 400 Italic', 'kickstart-business' ),
                'medium'                => esc_attr__( 'Medium 500', 'kickstart-business' ),
                'medium-italic'         => esc_attr__( 'Medium 500 Italic', 'kickstart-business' ),
                'semi-bold'             => esc_attr__( 'Semi-Bold 600', 'kickstart-business' ),
                'semi-bold-italic'      => esc_attr__( 'Semi-Bold 600 Italic', 'kickstart-business' ),
                'bold'                  => esc_attr__( 'Bold 700', 'kickstart-business' ),
                'bold-italic'           => esc_attr__( 'Bold 700 Italic', 'kickstart-business' ),
                'extra-bold'            => esc_attr__( 'Extra-Bold 800', 'kickstart-business' ),
                'extra-bold-italic'     => esc_attr__( 'Extra-Bold 800 Italic', 'kickstart-business' ),
                'ultra-bold'            => esc_attr__( 'Ultra-Bold 900', 'kickstart-business' ),
                'ultra-bold-italic'     => esc_attr__( 'Ultra-Bold 900 Italic', 'kickstart-business' ),
                'invalid-value'         => esc_attr__( 'Invalid Value', 'kickstart-business' ),
                'add-new'           	=> esc_attr__( 'Add new', 'kickstart-business' ),
                'row'           		=> esc_attr__( 'row', 'kickstart-business' ),
                'limit-rows'            => esc_attr__( 'Limit: %s rows', 'kickstart-business' ),
                'open-section'          => esc_attr__( 'Press return or enter to open this section', 'kickstart-business' ),
                'back'                  => esc_attr__( 'Back', 'kickstart-business' ),
                'reset-with-icon'       => sprintf( esc_attr__( '%s Reset', 'kickstart-business' ), '<span class="dashicons dashicons-image-rotate"></span>' ),
                'text-align'            => esc_attr__( 'Text Align', 'kickstart-business' ),
                'text-transform'        => esc_attr__( 'Text Transform', 'kickstart-business' ),
                'none'                  => esc_attr__( 'None', 'kickstart-business' ),
                'capitalize'            => esc_attr__( 'Capitalize', 'kickstart-business' ),
                'uppercase'             => esc_attr__( 'Uppercase', 'kickstart-business' ),
                'lowercase'             => esc_attr__( 'Lowercase', 'kickstart-business' ),
                'initial'               => esc_attr__( 'Initial', 'kickstart-business' ),
                'select-page'           => esc_attr__( 'Select a Page', 'kickstart-business' ),
                'open-editor'           => esc_attr__( 'Open Editor', 'kickstart-business' ),
                'close-editor'          => esc_attr__( 'Close Editor', 'kickstart-business' ),
                'switch-editor'         => esc_attr__( 'Switch Editor', 'kickstart-business' ),
                'hex-value'             => esc_attr__( 'Hex Value', 'kickstart-business' ),
            );

            // Apply global changes from the kirki/config filter.
            // This is generally to be avoided.
            // It is ONLY provided here for backwards-compatibility reasons.
            // Please use the kirki/{$config_id}/l10n filter instead.
            $config = apply_filters( 'kirki/config', array() );
            if ( isset( $config['i18n'] ) ) {
                $translation_strings = wp_parse_args( $config['i18n'], $translation_strings );
            }

            // Apply l10n changes using the kirki/{$config_id}/l10n filter.
            return apply_filters( 'kirki/' . $config_id . '/l10n', $translation_strings );

        }
    }
}
